#!/bin/bash

#---( Zenwalk Build Script
#---( Build Script written for gEDA Suite
#---( Home Page: http://www.gpleda.org/
#---( Source URL: http://www.gpleda.org/sources.html
#---( Source1: http://geda.seul.org/devel/v1.5/1.5.2/geda-gschem-1.5.2.tar.gz
#---( Source2: http://geda.seul.org/devel/v1.5/1.5.2/geda-gnetlist-1.5.2.tar.gz
#---( Source3: http://geda.seul.org/devel/v1.5/1.5.2/geda-gsymcheck-1.5.2.tar.gz
#---( Source4: http://geda.seul.org/devel/v1.5/1.5.2/geda-gattrib-1.5.2.tar.gz
#---( Source5: http://geda.seul.org/devel/v1.5/1.5.2/geda-utils-1.5.2.tar.gz
#---( Source6: http://geda.seul.org/devel/v1.5/1.5.2/geda-docs-1.5.2.tar.gz
#---( Source7: http://geda.seul.org/devel/v1.5/1.5.2/geda-examples-1.5.2.tar.gz

#---( Author:  R S Ananda Murthy (rsamurti@gmail.com)
#---( Date build script was last modified: Tuesday, 19-May-2009.


#------------------( Set Package Name & Version )


soft='geda-suite'
softversion='1.5.2'
packageversion='62.1'


#------------------( Check for source files )


if [ -f geda-gschem-$softversion.tar.gz ]; then
   echo "geda-gschem source file .. ok"
else
   echo "geda-gschem source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/devel/v1.5/1.5.2/$soft-gschem-$softversion.tar.gz
fi


if [ -f geda-gnetlist-$softversion.tar.gz ]; then
   echo "geda-gnetlist source file .. ok"
else
   echo "geda-gnetlist source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/devel/v1.5/1.5.2/$soft-gnetlist-$softversion.tar.gz
fi


if [ -f geda-gnetlist-$softversion.tar.gz ]; then
   echo "geda-gnetlist source file .. ok"
else
   echo "geda-gnetlist source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/devel/v1.5/1.5.2/$soft-gnetlist-$softversion.tar.gz
fi


if [ -f geda-gsymcheck-$softversion.tar.gz ]; then
   echo "geda-gsymcheck source file .. ok"
else
   echo "geda-gsymcheck source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/devel/v1.5/1.5.2/$soft-gsymcheck-$softversion.tar.gz
fi


if [ -f geda-gattrib-$softversion.tar.gz ]; then
   echo "geda-gattrib source file .. ok"
else
   echo "geda-gattrib source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/devel/v1.5/1.5.2/$soft-gattrib-$softversion.tar.gz
fi


if [ -f geda-utils-$softversion.tar.gz ]; then
   echo "geda-utils source file .. ok"
else
   echo "geda-utils source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/devel/v1.5/1.5.2/$soft-utils-$softversion.tar.gz
fi


if [ -f geda-docs-$softversion.tar.gz ]; then
   echo "geda-docs source file .. ok"
else
   echo "geda-docs source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/devel/v1.5/1.5.2/$soft-docs-$softversion.tar.gz
fi


if [ -f geda-examples-$softversion.tar.gz ]; then
   echo "geda-examples source file .. ok"
else
   echo "geda-examples source file does not exit. Downloading it ..."
   wget -c http://geda.seul.org/devel/v1.5/1.5.2/$soft-examples-$softversion.tar.gz
fi


#------------------( Set Package CPU Architecture Optimizations )


arch='i486'
cpu='i686'


#------------------( Set Build Location Variables )


buildir=$(pwd)
srcpkg1="$buildir/geda-docs-$softversion.tar.gz"
srcpkg2="$buildir/geda-gschem-$softversion.tar.gz"
srcpkg3="$buildir/geda-gnetlist-$softversion.tar.gz"
srcpkg4="$buildir/geda-gsymcheck-$softversion.tar.gz"
srcpkg5="$buildir/geda-gattrib-$softversion.tar.gz"
srcpkg6="$buildir/geda-utils-$softversion.tar.gz"
srcpkg7="$buildir/geda-examples-$softversion.tar.gz"

src1="geda-docs-$softversion"
src2="geda-gschem-$softversion"
src3="geda-gnetlist-$softversion"
src4="geda-gsymcheck-$softversion"
src5="geda-gattrib-$softversion"
src6="geda-utils-$softversion"
src7="geda-examples-$softversion"

package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"


#------------------( Clean, prepare the work area and extract the source code )


cd $buildir

rm -rf $src1
rm -rf $src2
rm -rf $src3
rm -rf $src4
rm -rf $src5
rm -rf $src6
rm -rf $src7

tar -xvf $srcpkg1
tar -xvf $srcpkg2
tar -xvf $srcpkg3
tar -xvf $srcpkg4
tar -xvf $srcpkg5
tar -xvf $srcpkg6
tar -xvf $srcpkg7

rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest


#------------------( Set Build Ownerships and CFLAGS )


chown -R root:root .
export CFLAGS="-O2 -march=$arch -mtune=$cpu" 


#------------------( Configure, Make And Install The Software )


# geda-docs
cd $buildir/$src1/
./configure --prefix=/usr --mandir=/usr/man || return 1
make || return 1
make DESTDIR=$dest install || return 1


# geda-gschem
cd $buildir/$src2/
./configure --prefix=/usr --disable-update-desktop-database --mandir=/usr/man || return 1
make || return 1
make DESTDIR=$dest install || return 1

	
# geda-gnetlist
cd $buildir/$src3/
./configure --prefix=/usr --mandir=/usr/man --docdir=/usr/doc/geda-suite-$softversion || return 1
make || return 1
make DESTDIR=$dest install || return 1

# geda-gsymcheck
cd $buildir/$src4/
./configure --prefix=/usr --mandir=/usr/man || return 1
make || return 1
make DESTDIR=$dest install || return 1

# geda-gattrib
cd $buildir/$src5/
./configure --prefix=/usr --disable-update-desktop-database --mandir=/usr/man || return 1
make || return 1
make DESTDIR=$dest install || return 1
	
# geda-utils
cd $buildir/$src6/
./configure --prefix=/usr --mandir=/usr/man || return 1
make || return 1
make DESTDIR=$dest install || return 1
	
# geda-examples
cd $buildir/$src7/
./configure --prefix=/usr --mandir=/usr/man || return 1
make || return 1
make DESTDIR=$dest install || return 1


#------------------( Strip Executables (Comment out these lines if debugging info is needed) )


( cd $dest
  find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded
)


#------------------( Compress Man Pages and Move To Correct Location )


( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)


#------------------( Move Documentation To Correct Location )


mkdir -p $dest/usr/doc/$soft-$softversion/geda-gschem-$softversion
cd $buildir/$src2/
cp -a AUTHORS BUGS COPYING TODO ABOUT-NLS README INSTALL $dest/usr/doc/$soft-$softversion/geda-gschem-$softversion
cp ./docs/* $dest/usr/doc/$soft-$softversion/geda-gschem-$softversion
mv ./examples $dest/usr/doc/$soft-$softversion/geda-gschem-$softversion

mkdir -p $dest/usr/doc/$soft-$softversion/geda-gnetlist-$softversion
cd $buildir/$src3/
cp -a AUTHORS BUGS COPYING NEWS TODO README INSTALL $dest/usr/doc/$soft-$softversion/geda-gnetlist-$softversion
cp ./docs/* $dest/usr/doc/$soft-$softversion/geda-gnetlist-$softversion
mv ./examples $dest/usr/doc/$soft-$softversion/geda-gnetlist-$softversion

mkdir -p $dest/usr/doc/$soft-$softversion/geda-gsymcheck-$softversion
cd $buildir/$src4/
cp -a AUTHORS BUGS COPYING TODO README INSTALL $dest/usr/doc/$soft-$softversion/geda-gsymcheck-$softversion
cp ./docs/* $dest/usr/doc/$soft-$softversion/geda-gsymcheck-$softversion

mkdir -p $dest/usr/doc/$soft-$softversion/geda-gattrib-$softversion
cd $buildir/$src5/
cp -a AUTHORS BUGS COPYING NEWS NOTES README INSTALL $dest/usr/doc/$soft-$softversion/geda-gattrib-$softversion

mkdir -p $dest/usr/doc/$soft-$softversion/geda-utils-$softversion
cd $buildir/$src6/
cp -a AUTHORS COPYING INSTALL README $dest/usr/doc/$soft-$softversion/geda-utils-$softversion

mv $dest/usr/share/doc/geda-doc/wiki $dest/usr/doc/$soft-$softversion
mv $dest/usr/share/doc/geda-doc/man $dest/usr/doc/$soft-$softversion
mv $dest/usr/share/doc/geda-doc/readmes $dest/usr/doc/$soft-$softversion
mv $dest/usr/share/doc/geda-doc/examples $dest/usr/doc/$soft-$softversion
mv $dest/usr/share/doc/geda-doc/gedadocs.html $dest/usr/doc/$soft-$softversion

( cd $dest/usr/share/doc; rm -rf geda-doc )
( cd $dest/usr/doc; ln -s $soft-$softversion geda-doc )


#------------------( Copy The Build Script )


mkdir -p $dest/usr/src/$soft-$softversion
cp $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion/build-$soft.sh


#------------------( Create The Slackdesc )


mkdir -p $dest/install
cat <<EOF > $dest/install/slack-desc 
          |-----handy-ruler------------------------------------------------------|
geda-suite: geda-suite (gEDA/gaf Suite)
geda-suite: 
geda-suite: Contains gschem, gnetlist, gsymcheck, gattrib, utilities,
geda-suite: documentation, and examples from the gEDA project.
geda-suite: 
geda-suite: 
geda-suite: 
geda-suite: 
geda-suite: 
geda-suite:
geda-suite:
EOF


#------------------( Compress The Package And Clean Up The Work Area )

cd $dest

find . -perm 640 -exec chmod 644 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 770 -exec chmod 755 {} \;
find . -perm 700 -exec chmod 755 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

makepkg -l y -c n ../$package.tlz
rm -rf $buildir/$src1
rm -rf $buildir/$src2
rm -rf $buildir/$src3
rm -rf $buildir/$src4
rm -rf $buildir/$src5
rm -rf $buildir/$src6
rm -rf $buildir/$src7
rm -rf $dest


#------------------( Generate the MD5 Check Sum )

cd $buildir
md5sum $package.tlz > $package.md5
zen-pkgcheck.pl $package.tlz
requiredbuilder -z $package.tlz > $package.dep
